

((PlbCustomDeepCopySupport createSubApplication: #PlbVisualAgeVendorCopySupport in: 'true') isNil)
    ifTrue: [SubApplication errorCouldNotCreate: #PlbVisualAgeVendorCopySupport]!

PlbVisualAgeVendorCopySupport becomeDefault!
SubApplication subclass: #PlbVisualAgeVendorCopySupport
    instanceVariableNames: ''
    classVariableNames: ''
    poolDictionaries: ''!


PlbVisualAgeVendorCopySupport becomeDefault!

!ArrayedCollection privateMethods !

plbVendorCopyContentsFrom: original using: copyStrategy
	"Populate the variable slots of the receiver with copies of each variable
	 slot of original created under the control of copyStrategy."

	original doWithIndex: [:item :index |
		self at: index put: (copyStrategy copy: item)
	].
! !

!Boolean privateMethods !

plbVendorCopyStructure
	"Booleans shouldn't be copied. Just answer the receiver."

	^self
! !

!Character privateMethods !

plbVendorCopyStructure
	"Characters shouldn't be copied. Just answer the receiver."

	^self
! !

!Collection privateMethods !

plbVendorCopyContentsFrom: original using: copyStrategy
	"Populate the receiver with copies of each element
	 of original created under the control of copyStrategy."

	original do: [:item| self add: (copyStrategy copy: item)].
!

plbVendorCopyStructure
	"Answer an unpopulated instance like the receiver. This 
	 skeleton instance will later be populated as each referenced
	 variable of the receiver is copied."

	^self class new: self size
! !

!EsAtom privateMethods !

plbVendorCopyStructure
	"Atoms shouldn't be copied. Just answer the receiver."

	^self
! !

!EsString privateMethods !

plbVendorCopyContentsFrom: original using: copyStrategy
	"Do nothing because the string has already been copied."
!

plbVendorCopyStructure
	"Answer a standard copy of the receiver."

	^self copy
! !

!Interval privateMethods !

plbVendorCopyContentsFrom: original using: copyStrategy
	"Do nothing because the structure copy already copied the contents."
!

plbVendorCopyStructure
	"Answer a standard copy of the receiver."

	^self copy
! !

!KeyedCollection privateMethods !

plbVendorCopyContentsFrom: original using: copyStrategy
	"Populate the receiver with copies of each element
	 of original created under the control of copyStrategy."

	original associationsDo: [:assoc | 
		self 
			at: assoc key
			put: (copyStrategy copy: assoc value)
	].
! !

!Number privateMethods !

plbVendorCopyContentsFrom: original using: copyStrategy
	"This method will only be run if a subclass of Number is created
	 that does not answer self when asked for a copy. The
	 situation is unlikely."
!

plbVendorCopyStructure
	"Answer a standard copy of the receiver."

	^self copy
! !

!Object publicMethods !

plbVendorCopy
	"Answer a true deep copy of the receiver while maintaining
	 references. Each referenced object will have the opportunity
	 to participate in the copy and decide how it should be copied."

	| copyStrategy |
	^(copyStrategy := PlbCopyStrategy new)
		structureCopyBlock: [:original | original plbVendorCopyStructure ];
		contentsCopyBlock: [:original :skeleton | skeleton plbVendorCopyContentsFrom: original using: copyStrategy ];
		copyRoot: self.
! !

!Object privateMethods !

plbVendorCopyContentsFrom: original using: copyStrategy
	"Populate the variable slots of the receiver with copies of each variable
	 slot of original created under the control of copyStrategy."

	self plbBasicCopyContentsFrom: original using: copyStrategy
!

plbVendorCopyStructure
	"Answer an unpopulated instance like the receiver. This 
	 skeleton instance will later be populated as each referenced
	 variable of the receiver is copied. Answer nil or the receiver
	 if the receiver shouldn't be copied."

	^self plbBasicCopyStructure
! !

!SortedCollection privateMethods !

plbVendorCopyStructure
	"Answer an unpopulated instance using the
	 same sort block as the receiver."

	^self class sortBlock: self sortBlock
! !

!Symbol privateMethods !

plbVendorCopyStructure
	"Symbols shouldn't be copied. Just answer the receiver."

	^self
! !

!UndefinedObject privateMethods !

plbVendorCopyStructure
	"nil shouldn't be copied. Just answer the receiver."

	^self
! !

PlbVisualAgeVendorCopySupport initializeAfterLoad!

PlbVisualAgeVendorCopySupport loaded!